@@ -3,9 +3,11 @@
  *
  * This plugin is released under the GPL
  */
+
+
 #define DETECT_WRAPPED_SVC
 #define SMART_TCP_RW
-/* #define DEBUG */
+/* #define DEBUG  */
 
 #include <includes.h>
 
@@ -57,7 +59,7 @@ plugin_init(desc)
 	struct arglist *desc;
 {
 	plug_set_id(desc, 10330);
-	plug_set_version(desc, "$Revision: 1.247 $");
+	plug_set_version(desc, "$Revision: 1.256 $");
 
 	plug_set_name(desc, FR_NAME, "francais");
 	plug_set_name(desc, EN_NAME, NULL);
@@ -399,9 +401,6 @@ mark_ssh_server(desc, port, buffer, trp)
 	int             trp;
 {
 	register_service(desc, port, "ssh");
-	while ((buffer[strlen(buffer) - 1] == '\n') ||
-	       (buffer[strlen(buffer) - 1] == '\r'))
-		buffer[strlen(buffer) - 1] = '\0';
 	post_note(desc, port, "An ssh server is running on this port");
 }
 
@@ -859,7 +858,7 @@ mark_smux_server(desc, port, buffer, trp)
 	char            msg[255];
 
 	register_service(desc, port, "smux");
-	snprintf(msg, sizeof(msg), "A SNMP Multiplexer (smux) seems to be running on this port%s",
+	snprintf(msg, sizeof(msg), "An SNMP Multiplexer (smux) seems to be running on this port%s",
 		 get_encaps_through(trp));
 	post_note(desc, port, msg);
 }
@@ -1447,7 +1446,6 @@ port_to_name(int port)
 	return NULL;
 }
 
-#if 0
 static void
 mark_unknown_svc(desc, port, banner, trp)
 	struct arglist *desc;
@@ -1460,18 +1458,7 @@ mark_unknown_svc(desc, port, banner, trp)
 	plug_set_key(desc, "Services/unknown", ARG_INT, (void *) port);
 	snprintf(tmp, sizeof(tmp), "unknown/banner/%d", port);
 	plug_replace_key(desc, tmp, ARG_STRING, (char *) banner);
-
-	norm = (char *) port_to_name(port);
-	*tmp = '\0';
-	if (norm != NULL) {
-		snprintf(tmp, sizeof(tmp), "An unknown service is running on this port%s.\n\
-It is usually reserved for %s",
-			 get_encaps_through(trp), norm);
-	}
-	if (*tmp != '\0')
-		post_note(desc, port, tmp);
 }
-#endif
 
 static void
 mark_gnuserv(desc, port)
@@ -1629,7 +1616,7 @@ mark_pnsclient(desc, port, buffer, trp)
 
 	register_service(desc, port, "pNSClient");
 
-	snprintf(ban, sizeof(ban), "A Netsaint plugin (pNSClient.exe) is running on this port%s",
+	snprintf(ban, sizeof(ban), "A Nagios plugin (pNSClient.exe) is running on this port%s",
 		 get_encaps_through(trp));
 	post_note(desc, port, ban);
 }
@@ -1869,7 +1856,7 @@ plugin_do_run(desc, h, test_ssl)
 			char           *line;
 			char           *origline;
 			int             trp, i;
-			char            buffer[2049];
+			unsigned char            buffer[2049];
 			unsigned char  *banner = NULL, *bannerHex = NULL;
 			int             banner_len;
 			int             port = atoi(h->name + len_head);
@@ -1887,6 +1874,13 @@ plugin_do_run(desc, h, test_ssl)
 			int             diff_tv = 0, diff_tv2 = 0;
 			int             type, no_banner_grabbed = 0;
 
+			if ( port == 139 || port == 445 )
+			{
+			 if ( h != NULL ) h = h->next;
+			 continue;
+			}
+	
+
 #define DIFFTV1000(t1,t2)	((t1.tv_sec - t2.tv_sec)*1000 + (t1.tv_usec - t2.tv_usec)/1000)
 
 			bzero(buffer, sizeof(buffer));
@@ -1897,6 +1891,7 @@ plugin_do_run(desc, h, test_ssl)
 #else
 			bannerHex = plug_get_key(desc, kb);
 #endif
+
 			if (type == ARG_STRING && bannerHex != NULL && bannerHex[0] != '\0') {
 				int             i, c1, c2;
 				banner_len = strlen((char *) bannerHex) / 2;
@@ -1904,23 +1899,33 @@ plugin_do_run(desc, h, test_ssl)
 					banner_len = sizeof(buffer) - 1;
 				for (i = 0; i < banner_len; i++) {
 					c1 = bannerHex[2 * i];
-					if (c1 >= 0 && c1 <= 9)
+					if (c1 >= '0' && c1 <= '9')
 						c1 -= '0';
 					else if (c1 >= 'a' && c1 <= 'f')
-						c1 -= 'a';
+						c1 = c1 - 'a' + 10;
 					else if (c1 >= 'A' && c1 <= 'F')
-						c1 -= 'A';
+						c1 = c1 - 'A' + 10;
 					else
+						{
+#ifdef DEBUG
+						printf("Invalid value '%x' (%c, off%d)\n", c1, c1, i * 2 + 1);
+#endif
 						banner_len = 0;	/* Invalid value */
+						}
 					c2 = bannerHex[2 * i + 1];
-					if (c2 >= 0 && c2 <= 9)
+					if (c2 >= '0' && c2 <= '9')
 						c2 -= '0';
 					else if (c2 >= 'a' && c2 <= 'f')
-						c2 -= 'a';
+						c2 = c2 - 'a' + 10;
 					else if (c2 >= 'A' && c2 <= 'F')
-						c2 -= 'A';
+						c2 = c2 - 'A' + 10;
 					else
+						{
+#ifdef DEBUG
+						printf("Invalid value '%x' (%c, off%d)\n", c2, c2, i * 2 + 1);
+#endif
 						banner_len = 0;	/* Invalid value */
+						}
 					buffer[i] = c1 << 4 | c2;
 				}
 				buffer[i] = '\0';
@@ -2135,8 +2140,9 @@ plugin_do_run(desc, h, test_ssl)
 					{
 						char            buf2[sizeof(buffer) * 2 + 1];
 						int             y, flag = 0;
+						char 		kbHex[64];
 
-						strcat(kb, "Hex");
+						snprintf(kbHex, sizeof(kbHex), "%sHex", kb);
 
 						if (len >= sizeof(buffer))
 							len = sizeof(buffer);
@@ -2148,7 +2154,7 @@ plugin_do_run(desc, h, test_ssl)
 						}
 						buf2[2 * y] = '\0';
 						if (flag)
-							plug_replace_key(desc, kb, ARG_STRING, buf2);
+							plug_replace_key(desc, kbHex, ARG_STRING, buf2);
 					}
 
 					origline = estrdup((char *) banner);
@@ -2473,7 +2479,7 @@ plugin_do_run(desc, h, test_ssl)
 			         * I'll clean this later. Meanwhile, we will not print a silly message
 			         * for rsh and rlogin.
 			         */
-				if (port == 513 /* rlogin */ || port == 514 /* rsh */ )
+				if (port == 512 /* rexec */ || port == 513 /* rlogin */ || port == 514 /* rsh */ )
 					maybe_wrapped = 0;
 
 				if (maybe_wrapped	/* && trp ==
@@ -2569,21 +2575,19 @@ and in %d.%03d when we just wait. It is  probably not wrapped\n",
 				}
 #endif
 
-				if (unindentified_service && port != 139)
+				if (unindentified_service && port != 139 && port != 445)
 					/*
 					 * port 139 can't be marked as
 					 * 'unknown'
 					 */
 				{
 					unknown[num_unknown++] = port;
-#if 0
 					/*
 					 * find_service_3digits will run
 					 * after us
 					 */
 					if (!three_digits)
 						mark_unknown_svc(desc, port, banner, trp);
-#endif
 				}
 				efree(&banner);
 			}
@@ -2725,7 +2729,7 @@ plugin_run(desc)
 	char           *cafile = get_plugin_preference(desc, CA_FILE);
 	char           *test_ssl_s = get_plugin_preference(desc, TEST_SSL_PREF);
 
-
+	
 
 	if (key && key[0] != '\0')
 		key = (char *) get_plugin_preference_fname(desc, key);
@@ -2861,6 +2865,10 @@ plugin_run(desc)
 #else
 				close(soc);
 				arg_set_value(desc, "pipe", -1, (void *) sons_pipe[i][0]);
+#endif
+#ifdef NESSUS3
+				store_close();
+				store_init_sys(NULL, 1);
 #endif
 				signal(SIGTERM, _exit);
 				plugin_do_run(desc, sons_args[i], test_ssl);
