@@ -439,7 +439,7 @@ find_rtt(struct in_addr dst, unsigned long *rtt)
 #if DEBUG > 1
 		printf("send to port %d\n", ports[i]);
 #endif
-
+		errno = 0;
 		e = sendto(soc, pkt, sizeof(struct ip) + sizeof(struct tcphdr), 0, (struct sockaddr *) & soca, sizeof(soca));
 		if (e < 0) {
 			perror("synscan->find_rtt->sendto ");
@@ -536,6 +536,7 @@ sendpacket(int soc, int bpf, int skip, struct in_addr dst, struct in_addr src, i
 	char           *res;
 	struct sockaddr_in soca;
   	struct timeval rtt_tv = timeval(*rtt);
+	static int retry = 0;
 
 	bzero(&soca, sizeof(soca));
 	soca.sin_family = AF_INET;
@@ -554,8 +555,20 @@ sendpacket(int soc, int bpf, int skip, struct in_addr dst, struct in_addr src, i
 	if (dport != 0) {
 		int             e;
 		packets = add_packet(packets, dport, ack);
+
+send:
+		errno = 0;
 		e = sendto(soc, pkt, sizeof(struct ip) + sizeof(struct tcphdr), 0, (struct sockaddr *) & soca, sizeof(soca));
 		if (e < 0) {
+			if ( errno == ENOBUFS )
+			{
+			 retry ++;
+			 if ( retry < 60 )
+				{
+				  sleep(1);
+				  goto send;
+				}
+			}
 			perror("synscan->sendpacket->sendto ");
 			return SCAN_FATAL_ERR;
 		}
@@ -691,7 +704,7 @@ PlugExport int
 plugin_init(struct arglist * desc)
 {
 	plug_set_id(desc, 11219);
-	plug_set_version(desc, "$Revision: 1.21 $");
+	plug_set_version(desc, "$Revision: 1.22 $");
 
 
 
